@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.cpp,v 1.24.4.2 2004/04/09 21:40:32 chpe Exp $
+ * $Id: EphyHeaderSniffer.cpp,v 1.24.4.6 2004/07/25 11:12:30 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,8 +49,6 @@
 #include "EphyHeaderSniffer.h"
 #include "netCore.h"
 
-#include "ephy-embed-single.h"
-#include "ephy-embed-shell.h"
 #include "ephy-file-chooser.h"
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
@@ -67,6 +65,7 @@
 #include "nsIMIMEInfo.h"
 #include "nsIDOMHTMLDocument.h"
 #include "nsIDownload.h"
+#include "nsIWindowWatcher.h"
 #if MOZILLA_SNAPSHOT > 10
 #include  "nsIMIMEHeaderParam.h"
 #endif
@@ -75,7 +74,8 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 EphyHeaderSniffer::EphyHeaderSniffer (nsIWebBrowserPersist* aPersist, MozillaEmbedPersist *aEmbedPersist,
-		nsIFile* aFile, nsIURI* aURL, nsIDOMDocument* aDocument, nsIInputStream* aPostData)
+		nsIFile* aFile, nsIURI* aURL, nsIDOMDocument* aDocument, nsIInputStream* aPostData,
+		EphyEmbedSingle *single)
 : mPersist(aPersist)
 , mEmbedPersist(aEmbedPersist)
 , mTmpFile(aFile)
@@ -84,14 +84,28 @@ EphyHeaderSniffer::EphyHeaderSniffer (nsIWebBrowserPersist* aPersist, MozillaEmb
 , mDocument(aDocument)
 , mPostData(aPostData)
 {
-	mPrompt = do_GetService("@mozilla.org/embedcomp/prompt-service;1");
-
 	LOG ("EphyHeaderSniffer ctor (%p)", this)
+
+	nsCOMPtr<nsIWindowWatcher> watcher
+		(do_GetService("@mozilla.org/embedcomp/window-watcher;1"));
+	if (!watcher) return;
+
+	watcher->GetNewAuthPrompter (nsnull, getter_AddRefs (mAuthPrompt));
+
+	mSingle = single;
+	g_object_add_weak_pointer (G_OBJECT (mSingle),
+				   (gpointer *)&mSingle);
 }
 
 EphyHeaderSniffer::~EphyHeaderSniffer()
 {
 	LOG ("EphyHeaderSniffer dtor (%p)", this)
+
+	if (mSingle)
+	{
+		g_object_remove_weak_pointer (G_OBJECT (mSingle),
+					      (gpointer *)&mSingle);
+	}
 }
 
 NS_IMPL_ISUPPORTS2(EphyHeaderSniffer, nsIWebProgressListener, nsIAuthPrompt)
@@ -99,15 +113,14 @@ NS_IMPL_ISUPPORTS2(EphyHeaderSniffer, nsIWebProgressListener, nsIAuthPrompt)
 NS_IMETHODIMP
 EphyHeaderSniffer::HandleContent ()
 {
-	EphyEmbedSingle *single;
 	gboolean handled = FALSE;
 	nsCString uriSpec;
 
-	if (mPostData) return NS_ERROR_FAILURE;
+	if (mPostData || !mSingle) return NS_ERROR_FAILURE;
 
-	mURL->GetSpec (uriSpec);	
-	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
-	g_signal_emit_by_name (single, "handle_content", mContentType.get(),
+	mURL->GetSpec (uriSpec);
+	
+	g_signal_emit_by_name (mSingle, "handle_content", mContentType.get(),
 			       uriSpec.get(), &handled);
 
 	return handled ? NS_OK : NS_ERROR_FAILURE;
@@ -231,7 +244,6 @@ filechooser_response_cb (EphyFileChooser *dialog, gint response, EphyHeaderSniff
 nsresult EphyHeaderSniffer::PerformSave (nsIURI* inOriginalURI)
 {
 	nsresult rv;
-	char *path, *download_dir;
 	EmbedPersistFlags flags;
 	PRBool askDownloadDest;
 
@@ -333,7 +345,7 @@ nsresult EphyHeaderSniffer::PerformSave (nsIURI* inOriginalURI)
         
 	/* Validate the file name to ensure legality. */
 	char *default_name = g_strdup (NS_ConvertUCS2toUTF8 (defaultFileName).get());
-	default_name = g_strdelimit (default_name, "/", ' ');
+	default_name = g_strdelimit (default_name, "/\\:", ' ');
 
 	const char *key;
 	key = ephy_embed_persist_get_persist_key (EPHY_EMBED_PERSIST (mEmbedPersist));
@@ -354,7 +366,6 @@ nsresult EphyHeaderSniffer::PerformSave (nsIURI* inOriginalURI)
 		EphyFileChooser *dialog;
 		GtkWindow *window;
 		const char *title;
-		int response;
 
 		title = ephy_embed_persist_get_fc_title (EPHY_EMBED_PERSIST (mEmbedPersist));
 		window = ephy_embed_persist_get_fc_parent (EPHY_EMBED_PERSIST (mEmbedPersist));
@@ -392,33 +403,3 @@ nsresult EphyHeaderSniffer::InitiateDownload (nsILocalFile *aDestFile)
 					mContentType.get(), mOriginalURI, mEmbedPersist,
 					mPostData, nsnull, -1);
 }
-
-NS_IMETHODIMP EphyHeaderSniffer::Prompt (const PRUnichar *dialogTitle, const PRUnichar *text,
-				         const PRUnichar *passwordRealm, PRUint32 savePassword,
-				         const PRUnichar *defaultText, PRUnichar **result, PRBool *_retval)
-{
-	if (defaultText) *result = ToNewUnicode(nsDependentString(defaultText));
-
-	return mPrompt->Prompt (nsnull, dialogTitle, text, result,
-				nsnull, nsnull, _retval);
-}                                                                                                                            
-
-NS_IMETHODIMP EphyHeaderSniffer::PromptUsernameAndPassword (const PRUnichar *dialogTitle, const PRUnichar *text,
-						            const PRUnichar *passwordRealm, PRUint32 savePassword,
-						            PRUnichar **user, PRUnichar **pwd, PRBool *_retval)
-{
-	*_retval = savePassword;
-
-	return mPrompt->PromptUsernameAndPassword (nsnull, dialogTitle, text, user, pwd,
-						   nsnull, nsnull, _retval);
-}
-
-NS_IMETHODIMP EphyHeaderSniffer::PromptPassword (const PRUnichar *dialogTitle, const PRUnichar *text,
-					         const PRUnichar *passwordRealm, PRUint32 savePassword,
-					         PRUnichar **pwd, PRBool *_retval)
-{
-	*_retval = savePassword;
-
-	return mPrompt->PromptPassword (nsnull, dialogTitle, text, pwd,
-					nsnull, nsnull, _retval);
-}
