@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.26 2004/02/29 14:24:40 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.26.4.6 2004/06/07 14:33:16 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,30 +24,24 @@
 #endif
 
 #include "FilePicker.h"
-
-#include "nsCRT.h"
-#include "nsCOMPtr.h"
-#include "nsISupportsArray.h"
-#include "nsIServiceManager.h"
-
-#include "nsString.h"
-#include "nsXPIDLString.h"
-#include "nsIPrefService.h"
-#include "nsIURI.h"
-#include "nsIFileURL.h"
-#include "nsIChannel.h"
-#include "nsIFileChannel.h"
-#include "nsNetCID.h"
-#include "nsILocalFile.h"
-#include "nsIPromptService.h"
-#include "nsReadableUtils.h"
-#include "nsIDOMWindow.h"
-#include "nsIDOMWindowInternal.h"
-#include "nsCOMPtr.h"
-#include "nsString.h"
-#include "nsILocalFile.h"
 #include "MozillaPrivate.h"
 
+#include <nsCOMPtr.h>
+#include <nsIServiceManager.h>
+#include <nsIURI.h>
+#include <nsIFileURL.h>
+#include <nsILocalFile.h>
+#include <nsIPromptService.h>
+#include <nsIDOMWindow.h>
+#include <nsNetCID.h>
+
+#include <nsString.h>
+#include <nsReadableUtils.h>
+
+#if MOZILLA_SNAPSHOT < 18
+#include <nsIDOMWindowInternal.h>
+#endif
+
 #include "ephy-string.h"
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
@@ -85,20 +79,27 @@ GFilePicker::~GFilePicker()
 	}
 }
 
-/* void init (in nsIDOMWindowInternal parent, in wstring title, in short mode); */
+/* void init (in nsIDOMWindow parent, in AString title, in short mode); */
+#if MOZILLA_SNAPSHOT < 18
 NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *title, PRInt16 mode)
+#else
+NS_IMETHODIMP GFilePicker::Init(nsIDOMWindow *parent, const nsAString& title, PRInt16 mode)
+#endif
 {
 	LOG ("GFilePicker::Init")
 
-	nsCOMPtr<nsIDOMWindow> dw = do_QueryInterface (parent);
-	if (dw)
+	if (parent)
 	{
-		GtkWidget *pwin = MozillaFindGtkParent (dw);
+		GtkWidget *pwin = MozillaFindGtkParent (parent);
 
 		gtk_window_set_transient_for (GTK_WINDOW (mDialog), GTK_WINDOW (pwin));
 	}
 
-	gtk_window_set_title (GTK_WINDOW (mDialog), NS_ConvertUCS2toUTF8 (title).get());
+#if MOZILLA_SNAPSHOT < 13
+	gtk_window_set_title (GTK_WINDOW (mDialog), NS_ConvertUCS2toUTF8(title).get());
+#else
+	gtk_window_set_title (GTK_WINDOW (mDialog), NS_ConvertUTF16toUTF8 (title).get());
+#endif
 
 	mMode = mode;
 
@@ -110,9 +111,9 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 			
 			gtk_dialog_add_buttons (GTK_DIALOG (mDialog),
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_OPEN, EPHY_RESPONSE_OPEN,
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), EPHY_RESPONSE_OPEN);
+			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), GTK_RESPONSE_ACCEPT);
 			break;
 
 		case nsIFilePicker::modeOpenMultiple:
@@ -124,9 +125,9 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 
 			gtk_dialog_add_buttons (GTK_DIALOG (mDialog),
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_OPEN, EPHY_RESPONSE_OPEN,
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), EPHY_RESPONSE_OPEN);
+			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), GTK_RESPONSE_ACCEPT);
 
 			break;
 
@@ -136,9 +137,9 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 	
 			gtk_dialog_add_buttons (GTK_DIALOG (mDialog),
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_SAVE, EPHY_RESPONSE_SAVE,
+						GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 						NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), EPHY_RESPONSE_SAVE);
+			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), GTK_RESPONSE_ACCEPT);
 			break;
 		default:
 			g_assert_not_reached ();
@@ -160,47 +161,86 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 
 	if (filterMask & nsIFilePicker::filterAll)
 	{
+#if MOZILLA_SNAPSHOT < 18
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("All files")).get(),
 			      NS_LITERAL_STRING ("*").get());
+#else
+		AppendFilter (NS_ConvertUTF8toUTF16 (_("All files")),
+			      NS_LITERAL_STRING ("*"));
+#endif
 	}
 	if (filterMask & nsIFilePicker::filterHTML)
 	{
+#if MOZILLA_SNAPSHOT < 18
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("HTML files")).get(),
 			      NS_LITERAL_STRING ("*.html; *.htm; *.shtml; *.xhtml").get());
+#else
+		AppendFilter (NS_ConvertUTF8toUTF16 (_("HTML files")),
+			      NS_LITERAL_STRING ("*.html; *.htm; *.shtml; *.xhtml"));
+#endif
 	}
 	if (filterMask & nsIFilePicker::filterText)
 	{
+#if MOZILLA_SNAPSHOT < 18
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("Text files")).get(),
 			      NS_LITERAL_STRING ("*.txt; *.text").get());
+#else
+		AppendFilter (NS_ConvertUTF8toUTF16 (_("Text files")),
+			      NS_LITERAL_STRING ("*.txt; *.text"));
+#endif
 	}
 	if (filterMask & nsIFilePicker::filterImages)
 	{
+#if MOZILLA_SNAPSHOT < 18
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("Image files")).get(),
 			      NS_LITERAL_STRING ("*.png; *.gif; *.jpeg; *.jpg").get());
+#else
+		AppendFilter (NS_ConvertUTF8toUTF16 (_("Image files")),
+			      NS_LITERAL_STRING ("*.png; *.gif; *.jpeg; *.jpg"));
+#endif
 	}
 	if (filterMask & nsIFilePicker::filterXML)
 	{
+#if MOZILLA_SNAPSHOT < 18
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("XML files")).get(),
 			      NS_LITERAL_STRING ("*.xml").get());
+#else
+		AppendFilter (NS_ConvertUTF8toUTF16 (_("XML files")),
+			      NS_LITERAL_STRING ("*.xml"));
+#endif
 	}
 	if (filterMask & nsIFilePicker::filterXUL)
 	{
+#if MOZILLA_SNAPSHOT < 18
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("XUL files")).get(),
 			      NS_LITERAL_STRING ("*.xul").get());
+#else
+		AppendFilter (NS_ConvertUTF8toUTF16 (_("XUL files")),
+			      NS_LITERAL_STRING ("*.xul"));
+#endif
 	}
 
 	return NS_OK;
 }
 
-/* void appendFilter (in wstring title, in wstring filter); */
+/* void appendFilter (in AString title, in AString filter); */
+#if MOZILLA_SNAPSHOT < 18
 NS_IMETHODIMP GFilePicker::AppendFilter(const PRUnichar *title, const PRUnichar *filter)
+#else
+NS_IMETHODIMP GFilePicker::AppendFilter(const nsAString& title, const nsAString& filter)
+#endif
 {
 	LOG ("GFilePicker::AppendFilter title '%s' for '%s'",
 	     NS_ConvertUCS2toUTF8 (title).get(),
 	     NS_ConvertUCS2toUTF8 (filter).get())
 
-	nsCAutoString pattern = NS_ConvertUCS2toUTF8 (filter);
+#if MOZILLA_SNAPHOST < 13
+	NS_ConvertUCS2toUTF8 pattern(filter);
+#else
+	NS_ConvertUTF16toUTF8 pattern(filter);
+#endif
 	pattern.StripWhitespace();
+	if (pattern.IsEmpty()) return NS_ERROR_FAILURE;
 
 	char **patterns = g_strsplit (pattern.get(), ";", -1);
 
@@ -211,7 +251,11 @@ NS_IMETHODIMP GFilePicker::AppendFilter(const PRUnichar *title, const PRUnichar
 		gtk_file_filter_add_pattern (filth, patterns[i]);
 	}
 
+#if MOZILLA_SNAPHOST < 13
 	gtk_file_filter_set_name (filth, NS_ConvertUCS2toUTF8(title).get());
+#else
+	gtk_file_filter_set_name (filth, NS_ConvertUTF16toUTF8(title).get());
+#endif
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (mDialog), filth);
 
 	g_strfreev (patterns);
@@ -219,53 +263,69 @@ NS_IMETHODIMP GFilePicker::AppendFilter(const PRUnichar *title, const PRUnichar
 	return NS_OK;
 }
 
-/* attribute wstring defaultString; */
+/* attribute AString defaultString; */
+#if MOZILLA_SNAPSHOT < 18
 NS_IMETHODIMP GFilePicker::GetDefaultString(PRUnichar **aDefaultString)
+#else
+NS_IMETHODIMP GFilePicker::GetDefaultString(nsAString& aDefaultString)
+#endif
 {
-	char *filename, *converted;
-
 	LOG ("GFilePicker::GetDefaultString")
 
-	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
-	if (filename != NULL)
-	{
-		converted = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
-
-		/* FIXME: when can depend on moz >= 1.6, use CopyUTF8toUCS2 here */
-		*aDefaultString = ToNewUnicode (NS_ConvertUTF8toUCS2 (converted));
-	
-		g_free (filename);
-		g_free (converted);
-	}
+#if MOZILLA_SNAPSHOT < 18
+	*aDefaultString = ToNewUnicode (mDefaultString);
+#else
+	aDefaultString = mDefaultString;
+#endif
 
 	return NS_OK;
 }
 
+#if MOZILLA_SNAPSHOT < 18
 NS_IMETHODIMP GFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
+#else
+NS_IMETHODIMP GFilePicker::SetDefaultString(const nsAString& aDefaultString)
+#endif
 {
 	LOG ("GFilePicker::SetDefaultString to %s",
 	     NS_ConvertUCS2toUTF8 (aDefaultString).get())
 
-	if (aDefaultString)
+	mDefaultString.Assign (aDefaultString);
+
+	if (mMode == nsIFilePicker::modeSave)
 	{
 		/* set_current_name takes UTF-8, not a filename */
+#if MOZILLA_SNAPSHOT < 13
 		gtk_file_chooser_set_current_name
 			(GTK_FILE_CHOOSER (mDialog),
-			 NS_ConvertUCS2toUTF8 (aDefaultString).get());
+			 NS_ConvertUCS2toUTF8 (mDefaultString).get());
+#else
+		gtk_file_chooser_set_current_name
+			(GTK_FILE_CHOOSER (mDialog),
+			 NS_ConvertUTF16toUTF8 (mDefaultString).get());
+#endif
 	}
 
 	return NS_OK;
 }
 
-/* attribute wstring defaultExtension; */
+/* attribute AString defaultExtension; */
+#if MOZILLA_SNAPSHOT < 18
 NS_IMETHODIMP GFilePicker::GetDefaultExtension(PRUnichar **aDefaultExtension)
+#else
+NS_IMETHODIMP GFilePicker::GetDefaultExtension(nsAString& aDefaultExtension)
+#endif
 {
 	LOG ("GFilePicker::GetDefaultExtension")
 
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+#if MOZILLA_SNAPSHOT < 18
 NS_IMETHODIMP GFilePicker::SetDefaultExtension(const PRUnichar *aDefaultExtension)
+#else
+NS_IMETHODIMP GFilePicker::SetDefaultExtension(const nsAString& aDefaultExtension)
+#endif
 {
 	LOG ("GFilePicker::SetDefaultExtension to %s",
 	     NS_ConvertUCS2toUTF8(aDefaultExtension).get())
@@ -316,8 +376,26 @@ NS_IMETHODIMP GFilePicker::SetDisplayDirectory(nsILocalFile *aDisplayDirectory)
 
 	LOG ("GFilePicker::SetDisplayDirectory to %s", dir.get())
 
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (mDialog),
-					     dir.get());
+	if (!mDefaultString.IsEmpty() && mMode != nsIFilePicker::modeSave)
+	{
+		char *defaultString, *filename;
+
+		defaultString = g_filename_from_utf8 (NS_ConvertUCS2toUTF8(mDefaultString).get(),
+						      -1, NULL, NULL, NULL);
+		if (defaultString)
+		{
+			filename = g_build_filename (dir.get(), defaultString, NULL);
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (mDialog), filename);
+			g_free (filename);
+		}
+		g_free (defaultString);
+
+	}
+	else
+	{
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (mDialog),
+						     dir.get());
+	}
 
 	return NS_OK;
 }
@@ -379,31 +457,29 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 
 	gtk_widget_show (GTK_WIDGET (mDialog));
 
-	int response = gtk_dialog_run (GTK_DIALOG (mDialog));
+	int response;
+	char *filename = NULL;
 
-	LOG ("GFilePicker::Show response=%d", response)
-
-	switch (response)
+	do
 	{
-		case EPHY_RESPONSE_OPEN:
-		case EPHY_RESPONSE_SAVE:
-			*_retval = nsIFilePicker::returnOK;
-			break;
-		default:
-			*_retval = nsIFilePicker::returnCancel;
-			break;
+		response = gtk_dialog_run (GTK_DIALOG (mDialog));
+
+		g_free (filename);
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
+
+		LOG ("GFilePicker::Show response=%d, filename=%s", response, filename)
 	}
+	while (response == GTK_RESPONSE_ACCEPT &&
+	       mMode == nsIFilePicker::modeSave &&
+	       !ephy_gui_confirm_overwrite_file (GTK_WIDGET (mDialog), filename));
 
 	gtk_widget_hide (GTK_WIDGET (mDialog));
-	
-	char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
 
-	if (filename == NULL)
+	if (response == GTK_RESPONSE_ACCEPT && filename != NULL)
 	{
-		*_retval = nsIFilePicker::returnCancel;
+		*_retval = nsIFilePicker::returnOK;
 	}
-	else if (mMode == nsIFilePicker::modeSave
-		 && ephy_gui_confirm_overwrite_file (GTK_WIDGET (mDialog), filename) == FALSE)
+	else
 	{
 		*_retval = nsIFilePicker::returnCancel;
 	}
