@@ -44,6 +44,8 @@
 #include "nsICRLInfo.h"
 #include "nsISimpleEnumerator.h"
 #include "nsIArray.h"
+#include "nsString.h"
+#include "nsReadableUtils.h"
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtkdialog.h>
@@ -207,12 +209,11 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWidget *gparent = MozillaFindGtkParent (parent);
 
-        g_return_val_if_fail (GTK_IS_WINDOW (gparent), GTK_RESPONSE_CANCEL);
         g_return_val_if_fail (markup_text, GTK_RESPONSE_CANCEL);
         g_return_val_if_fail (!checkbox_text || checkbox_value, GTK_RESPONSE_CANCEL);
 	
 	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (gparent),
+					      gparent ? GTK_WINDOW (gparent) : NULL,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      NULL);
 
@@ -286,10 +287,10 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
 
 	cert->GetCommonName (commonName);
 
- 	ttTargetUrl = g_strdup_printf ("\"<tt>%s</tt>\"", 
+ 	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
                                         PromiseFlatCString(targetURL).get());
 
-	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
+	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
                                          NS_ConvertUCS2toUTF8(commonName).get());
 
         first = g_strdup_printf (_("The site %s returned security information for "
@@ -331,7 +332,7 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 
 	cert->GetCommonName (commonName);
 
-	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
+	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
 					NS_ConvertUCS2toUTF8(commonName).get());
 
 	secondary = g_strdup_printf
@@ -435,7 +436,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 		  localtime_r (&t, &tm));
 	fdate = g_locale_to_utf8 (formattedDate, -1, NULL, NULL, NULL);
 
-	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
+	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
                                         NS_ConvertUCS2toUTF8(commonName).get());
 
 	secondary = g_strdup_printf (text, ttCommonName, fdate);
@@ -481,10 +482,10 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 
 	cert->GetCommonName (commonName);
 
-	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
+	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
 					NS_ConvertUCS2toUTF8(commonName).get());
 
-	ttTargetUrl = g_strdup_printf ("\"<tt>%s</tt>\"", 
+	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
 				       PromiseFlatCString(targetURL).get());
 
 	primary = g_strdup_printf (_("Cannot establish connection to %s."),
@@ -543,7 +544,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 
 	nsAutoString commonName;
 	cert->GetCommonName (commonName);
-	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
+	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
 					 NS_ConvertUCS2toUTF8(commonName).get());
 
 	tertiary = g_strdup_printf (_("Trust %s to identify:"), ttCommonName );
@@ -1187,6 +1188,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						  G_TYPE_STRING,
 						  G_TYPE_POINTER);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (chain_tree_view), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -1208,6 +1210,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 				    G_TYPE_STRING,
 				    G_TYPE_POINTER);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (field_tree_view), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
 
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (field_tree_view),
