@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.cpp,v 1.9 2004/02/28 10:47:03 marco Exp $
+ *  $Id: MozillaPrivate.cpp,v 1.9.4.2 2004/07/10 18:45:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +29,8 @@
 #include <nsIEmbeddingSiteWindow.h>
 #include <nsIWebBrowserChrome.h>
 #include <gtkmozembed.h>
+#include <nsReadableUtils.h>
+#include <nsString.h>
 
 #include "ephy-embed.h"
 #include "mozilla-embed.h"
@@ -74,7 +76,8 @@ GtkWidget *MozillaFindGtkParent (nsIDOMWindow *aDOMWindow)
 #define MM_TO_INCH(x)		(((double) x) / 25.4)
 
 NS_METHOD MozillaCollatePrintSettings (const EmbedPrintInfo *info,
-					  nsIPrintSettings *options)
+				       nsIPrintSettings *options,
+				       gboolean preview)
 {
 	const static int frame_types[] = {
                 nsIPrintSettings::kFramesAsIs,
@@ -127,7 +130,7 @@ NS_METHOD MozillaCollatePrintSettings (const EmbedPrintInfo *info,
 	 * in print preview mode if we set "print to file" to true.
 	 * See epiphany bug #119818.
 	 */
-	if (info->preview)
+	if (preview)
 	{
 		options->SetPrintToFile (PR_FALSE);
 	}
