@@ -29,7 +29,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkeditable.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 #include <string.h>
 
 #include "ephy-new-bookmark.h"
@@ -260,7 +260,7 @@ ephy_new_bookmark_construct (EphyNewBookmark *editor)
 	gtk_window_set_title (GTK_WINDOW (editor),
 			      _("Add Bookmark"));
 	icon = gtk_widget_render_icon (GTK_WIDGET (editor),
-				       EPHY_STOCK_BOOKMARK_PAGE,
+				       STOCK_ADD_BOOKMARK,
 				       GTK_ICON_SIZE_MENU,
 				       NULL);
 	gtk_window_set_icon (GTK_WINDOW (editor), icon);
@@ -332,7 +332,7 @@ duplicate_dialog_construct (GtkWindow *parent,
 	label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	tmp_title = g_strconcat ("<b>", title, "</b>", NULL);
+	tmp_title = g_markup_printf_escaped ("<b>%s</b>", title);
 	tmp_str = g_strdup_printf (_("A bookmark titled %s already exists for this page."),
 			           tmp_title);
 	str = g_strconcat ("<big>", tmp_str, "</big>", NULL);
