@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.79 2003/12/07 10:23:31 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.84.4.1 2004/07/10 18:45:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,7 +76,6 @@ struct EphyShellPrivate
 	GtkWidget *history_window;
 	GObject *pdm_dialog;
 	GObject *prefs_dialog;
-	GObject *print_setup_dialog;
 	GList *del_on_exit;
 	guint server_timeout;
 };
@@ -192,7 +191,6 @@ ephy_shell_init (EphyShell *shell)
 	shell->priv->bme = NULL;
 	shell->priv->history_window = NULL;
 	shell->priv->pdm_dialog = NULL;
-	shell->priv->print_setup_dialog = NULL;
 	shell->priv->toolbars_model = NULL;
 	shell->priv->fs_toolbars_model = NULL;
 	shell->priv->extensions_manager = NULL;
@@ -431,15 +429,6 @@ ephy_shell_startup (EphyShell *shell,
 	return !(result == Bonobo_ACTIVATION_REG_ALREADY_ACTIVE);
 }
 
-static void
-delete_files (GList *l)
-{
-	for (; l != NULL; l = l->next)
-	{
-		unlink (l->data);
-	}
-}
-
 static void
 ephy_shell_finalize (GObject *object)
 {
@@ -456,10 +445,6 @@ ephy_shell_finalize (GObject *object)
 	LOG ("Unref extension manager")
 	g_object_unref (shell->priv->extensions_manager);
 
-	delete_files (shell->priv->del_on_exit);
-	g_list_foreach (shell->priv->del_on_exit, (GFunc)g_free, NULL);
-	g_list_free (shell->priv->del_on_exit);
-
 	LOG ("Unref toolbars model")
 	if (shell->priv->toolbars_model)
 	{
@@ -496,12 +481,6 @@ ephy_shell_finalize (GObject *object)
 		g_object_unref (shell->priv->prefs_dialog);
 	}
 
-	LOG ("Unref print setup dialog")
-	if (shell->priv->print_setup_dialog)
-	{
-		g_object_unref (shell->priv->print_setup_dialog);
-	}
-
 	LOG ("Unref bookmarks")
 	if (shell->priv->bookmarks)
 	{
@@ -590,7 +569,7 @@ ephy_shell_new_tab (EphyShell *shell,
 		window = ephy_window_new ();
 	}
 
-	toolbar = ephy_window_get_toolbar (window);
+	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
 
 	if (previous_tab)
 	{
@@ -613,8 +592,9 @@ ephy_shell_new_tab (EphyShell *shell,
 	}
 
 	tab = ephy_tab_new ();
+	gtk_widget_show (GTK_WIDGET (tab));
 	embed = ephy_tab_get_embed (tab);
-	gtk_widget_show (GTK_WIDGET(embed));
+
 	ephy_window_add_tab (window, tab,
 			     position,
 			     jump_to);
@@ -723,8 +703,12 @@ ephy_shell_get_extensions_manager (EphyShell *es)
 
 	if (es->priv->extensions_manager == NULL)
 	{
-		/* Instantiate extensions manager; this will load the extensions */
+		/* Instantiate extensions manager */
 		es->priv->extensions_manager = ephy_extensions_manager_new ();
+
+		/* load the extensions */
+		ephy_extensions_manager_load_dir (es->priv->extensions_manager,
+						  EXTENSIONS_DIR);
 	}
 
 	return G_OBJECT (es->priv->extensions_manager);
@@ -781,8 +765,8 @@ ephy_shell_get_history_window (EphyShell *shell)
 
 	if (shell->priv->history_window == NULL)
 	{
-		history = ephy_embed_shell_get_global_history
-			(EPHY_EMBED_SHELL (ephy_shell));
+		history = EPHY_HISTORY
+			(ephy_embed_shell_get_global_history (embed_shell));
 		g_assert (history != NULL);
 		shell->priv->history_window = ephy_history_window_new (history);
 
@@ -822,24 +806,3 @@ ephy_shell_get_prefs_dialog (EphyShell *shell)
 
 	return shell->priv->prefs_dialog;
 }
-
-GObject *
-ephy_shell_get_print_setup_dialog (EphyShell *shell)
-{
-	if (shell->priv->print_setup_dialog == NULL)
-	{
-		shell->priv->print_setup_dialog = G_OBJECT (ephy_print_setup_dialog_new ());
-
-		g_object_add_weak_pointer (shell->priv->print_setup_dialog,
-					   (gpointer *) &shell->priv->print_setup_dialog);
-	}
-
-	return shell->priv->print_setup_dialog;
-}
-
-void
-ephy_shell_delete_on_exit (EphyShell *shell, const char *path)
-{
-	shell->priv->del_on_exit = g_list_append (shell->priv->del_on_exit,
-						  g_strdup (path));
-}
